"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextBody = void 0;
const OdfElement_1 = require("../OdfElement");
const text_1 = require("../text");
/**
 * This class represents the content of a text document.
 *
 * @example
 * const body = document.getBody();
 * body.addHeading('My document');
 * body.addParagraph('This is the first paragraph');
 * body.addHeading('Subheadline', 2);
 *
 * @since 0.7.0
 */
class TextBody extends OdfElement_1.OdfElement {
    /**
     * Adds a heading at the end of the document.
     * If a text is given, this will be set as text content of the heading.
     *
     * @param {string} [text] The text content of the heading
     * @param {number} [level=1] The heading level; defaults to 1 if omitted
     * @returns {Heading} The newly added heading
     * @since 0.7.0
     */
    addHeading(text, level = 1) {
        const heading = new text_1.Heading(text, level);
        this.append(heading);
        return heading;
    }
    /**
     * Adds an empty list at the end of the document.
     *
     * @example
     * new TextBody()
     *   .addList();
     *
     * @returns {List} The newly added list
     * @since 0.7.0
     */
    addList() {
        const list = new text_1.List();
        this.append(list);
        return list;
    }
    /**
     * Adds a paragraph at the end of the document.
     * If a text is given, this will be set as text content of the paragraph.
     *
     * @param {string} [text] The text content of the paragraph
     * @returns {Paragraph} The newly added paragraph
     * @since 0.7.0
     */
    addParagraph(text) {
        const paragraph = new text_1.Paragraph(text);
        this.append(paragraph);
        return paragraph;
    }
}
exports.TextBody = TextBody;
