import { Meta } from '../meta';
import { CommonStyles } from './CommonStyles';
import { FontFaceDeclarations } from './FontFaceDeclarations';
import { TextBody } from './TextBody';
export declare const XML_DECLARATION = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
/**
 * This class represents a text document in OpenDocument format.
 *
 * @example
 * const document = new TextDocument();
 * document.getMeta().setCreator('Homer Simpson');
 * document.getFontFaceDeclarations().create('FreeSans', 'FreeSans', FontPitch.Variable);
 * document.getCommonStyles().createParagraphStyle('Summary');
 * document.getBody().addHeading('My first document');
 * document.saveFlat('/home/homer/document.fodt');
 *
 * @since 0.1.0
 */
export declare class TextDocument {
    private meta;
    private fontFaceDeclarations;
    private commonStyles;
    private body;
    /**
     * Creates a `TextDocument` instance that represents a OpenDocument text document.
     *
     * @example
     * const document = new TextDocument();
     *
     * @since 0.1.0
     */
    constructor();
    /**
     * The `getBody()` method returns the content of the document.
     *
     * @example
     * new TextDocument()
     *   .getBody()
     *   .addHeading('My first document');
     *
     * @returns {TextBody} A `TextBody` object that holds the content of the document
     * @since 0.7.0
     */
    getBody(): TextBody;
    /**
     * The `getCommonStyles()` method returns the named styles of the document.
     *
     * @example
     * new TextDocument()
     *   .getCommonStyles()
     *   .createParagraphStyle('Summary');
     *
     * @returns {CommonStyles} A `CommonStyles` object that holds the named styles of the document
     * @since 0.9.0
     */
    getCommonStyles(): CommonStyles;
    /**
     * The `getFontFaceDeclarations()` method returns the font face declarations of the document.
     *
     * @example
     * new TextDocument()
     *   .getFontFaceDeclarations()
     *   .create('FreeSans', 'FreeSans', FontPitch.Variable);
     *
     * @returns {FontFaceDeclarations} An object holding the font faces of the document
     * @since 0.8.0
     */
    getFontFaceDeclarations(): FontFaceDeclarations;
    /**
     * The `getMeta()` method returns the metadata of the document.
     *
     * @example
     * new TextDocument()
     *   .getMeta()
     *   .setCreator('Homer Simpson');
     *
     * @returns {Meta} An object holding the metadata of the document
     * @since 0.6.0
     */
    getMeta(): Meta;
    /**
     * The `saveFlat()` method converts the document into an XML string and stores it in flat open document xml format.
     *
     * @example
     * new TextDocument()
     *   .saveFlat('/home/homer/document.fodt');
     *
     * @param {string} filePath The file path to write to
     * @returns {Promise<void>}
     * @since 0.1.0
     */
    saveFlat(filePath: string): Promise<void>;
    /**
     * Returns the string representation of this document in flat open document xml format.
     *
     * @returns {string} The string representation of this document
     * @since 0.1.0
     */
    toString(): string;
}
