"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextDocument = exports.XML_DECLARATION = void 0;
const fs_1 = require("fs");
const util_1 = require("util");
const xmldom_1 = require("xmldom");
const TextDocumentWriter_1 = require("../../xml/TextDocumentWriter");
const meta_1 = require("../meta");
const CommonStyles_1 = require("./CommonStyles");
const FontFaceDeclarations_1 = require("./FontFaceDeclarations");
const TextBody_1 = require("./TextBody");
exports.XML_DECLARATION = '<?xml version="1.0" encoding="UTF-8"?>\n';
/**
 * This class represents a text document in OpenDocument format.
 *
 * @example
 * const document = new TextDocument();
 * document.getMeta().setCreator('Homer Simpson');
 * document.getFontFaceDeclarations().create('FreeSans', 'FreeSans', FontPitch.Variable);
 * document.getCommonStyles().createParagraphStyle('Summary');
 * document.getBody().addHeading('My first document');
 * document.saveFlat('/home/homer/document.fodt');
 *
 * @since 0.1.0
 */
class TextDocument {
    /**
     * Creates a `TextDocument` instance that represents a OpenDocument text document.
     *
     * @example
     * const document = new TextDocument();
     *
     * @since 0.1.0
     */
    constructor() {
        this.meta = new meta_1.Meta();
        this.fontFaceDeclarations = new FontFaceDeclarations_1.FontFaceDeclarations();
        this.commonStyles = new CommonStyles_1.CommonStyles();
        this.body = new TextBody_1.TextBody();
    }
    /**
     * The `getBody()` method returns the content of the document.
     *
     * @example
     * new TextDocument()
     *   .getBody()
     *   .addHeading('My first document');
     *
     * @returns {TextBody} A `TextBody` object that holds the content of the document
     * @since 0.7.0
     */
    getBody() {
        return this.body;
    }
    /**
     * The `getCommonStyles()` method returns the named styles of the document.
     *
     * @example
     * new TextDocument()
     *   .getCommonStyles()
     *   .createParagraphStyle('Summary');
     *
     * @returns {CommonStyles} A `CommonStyles` object that holds the named styles of the document
     * @since 0.9.0
     */
    getCommonStyles() {
        return this.commonStyles;
    }
    /**
     * The `getFontFaceDeclarations()` method returns the font face declarations of the document.
     *
     * @example
     * new TextDocument()
     *   .getFontFaceDeclarations()
     *   .create('FreeSans', 'FreeSans', FontPitch.Variable);
     *
     * @returns {FontFaceDeclarations} An object holding the font faces of the document
     * @since 0.8.0
     */
    getFontFaceDeclarations() {
        return this.fontFaceDeclarations;
    }
    /**
     * The `getMeta()` method returns the metadata of the document.
     *
     * @example
     * new TextDocument()
     *   .getMeta()
     *   .setCreator('Homer Simpson');
     *
     * @returns {Meta} An object holding the metadata of the document
     * @since 0.6.0
     */
    getMeta() {
        return this.meta;
    }
    /**
     * The `saveFlat()` method converts the document into an XML string and stores it in flat open document xml format.
     *
     * @example
     * new TextDocument()
     *   .saveFlat('/home/homer/document.fodt');
     *
     * @param {string} filePath The file path to write to
     * @returns {Promise<void>}
     * @since 0.1.0
     */
    saveFlat(filePath) {
        const writeFileAsync = util_1.promisify(fs_1.writeFile);
        const xml = this.toString();
        return writeFileAsync(filePath, xml);
    }
    /**
     * Returns the string representation of this document in flat open document xml format.
     *
     * @returns {string} The string representation of this document
     * @since 0.1.0
     */
    toString() {
        const document = new TextDocumentWriter_1.TextDocumentWriter().write(this);
        return exports.XML_DECLARATION + new xmldom_1.XMLSerializer().serializeToString(document);
    }
}
exports.TextDocument = TextDocument;
