"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hyperlink = void 0;
const OdfTextElement_1 = require("./OdfTextElement");
/**
 * This class represents a hyperlink in a paragraph.
 *
 * @example
 * document.getBody()
 *   .addParagraph('This is a ')
 *   .addHyperlink('link', 'https://example.com/');
 *
 * @since 0.3.0
 */
class Hyperlink extends OdfTextElement_1.OdfTextElement {
    /**
     * Creates a hyperlink
     *
     * @example
     * new Hyperlink('My website', 'https://example.com/');
     *
     * @param {string} text The text content of the hyperlink
     * @param {string} uri The target URI of the hyperlink
     * @since 0.3.0
     */
    constructor(text, uri) {
        super(text);
        this.uri = uri;
    }
    /**
     * The `setURI()` method sets the target URI for this hyperlink.
     * If an illegal value is provided, the value will be ignored.
     *
     * @example
     * const hyperlink = new Hyperlink('My website', 'https://example.com/');
     * hyperlink.setURI('https://github.com'); // https://github.com
     * hyperlink.setURI('');                   // https://github.com
     *
     * @param {string} uri The target URI of this hyperlink
     * @returns {Hyperlink} The `Hyperlink` object
     * @since 0.3.0
     */
    setURI(uri) {
        if (typeof uri === 'string' && uri.trim().length > 0) {
            this.uri = uri;
        }
        return this;
    }
    /**
     * The `getURI()` method returns the target URI of this hyperlink.
     *
     * @example
     * const hyperlink = new Hyperlink('My website', 'https://example.com/');
     * hyperlink.getURI();                     // https://example.com
     * hyperlink.setURI('https://github.com');
     * hyperlink.getURI();                     // https://github.com
     *
     * @returns {string} The target URI of this hyperlink
     * @since 0.3.0
     */
    getURI() {
        return this.uri;
    }
}
exports.Hyperlink = Hyperlink;
