"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListItem = void 0;
const OdfElement_1 = require("../OdfElement");
const Heading_1 = require("./Heading");
const List_1 = require("./List");
const Paragraph_1 = require("./Paragraph");
/**
 * This class represents an item in a list.
 *
 * @example
 * const listItem = new ListItem();
 * listItem.addHeading('headline');
 * listItem.addParagraph('paragraph');
 * const subList = listItem.addList();
 *
 * @since 0.2.0
 */
class ListItem extends OdfElement_1.OdfElement {
    /**
     * Creates a `ListItem` instance that represents an item in a list.
     *
     * @example
     * new ListItem();
     *
     * @since 0.2.0
     */
    constructor() {
        super();
    }
    /**
     * Adds a heading at the end of the list item.
     * If a text is given, this will be set as text content of the heading.
     *
     * @param {string} [text] The text content of the heading
     * @param {number} [level=1] The heading level; defaults to 1 if omitted
     * @returns {Heading} The newly added heading
     * @since 0.11.0
     */
    addHeading(text, level = 1) {
        const heading = new Heading_1.Heading(text, level);
        this.append(heading);
        return heading;
    }
    /**
     * Adds an empty list at the end of the list item.
     *
     * @example
     * new ListItem()
     *   .addList();
     *
     * @returns {List} The newly added list
     * @since 0.11.0
     */
    addList() {
        const list = new List_1.List();
        this.append(list);
        return list;
    }
    /**
     * Adds a paragraph at the end of the list item.
     * If a text is given, this will be set as text content of the paragraph.
     *
     * @param {string} [text] The text content of the paragraph
     * @returns {Paragraph} The newly added paragraph
     * @since 0.11.0
     */
    addParagraph(text) {
        const paragraph = new Paragraph_1.Paragraph(text);
        this.append(paragraph);
        return paragraph;
    }
}
exports.ListItem = ListItem;
