"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextDocumentWriter = void 0;
const xmldom_1 = require("xmldom");
const office_1 = require("../api/office");
const MetaWriter_1 = require("./meta/MetaWriter");
const FontFaceDeclarationsWriter_1 = require("./office/FontFaceDeclarationsWriter");
const StylesWriter_1 = require("./office/StylesWriter");
const AutomaticStyleVisitor_1 = require("./AutomaticStyleVisitor");
const DomVisitor_1 = require("./DomVisitor");
const OdfAttributeName_1 = require("./OdfAttributeName");
const OdfElementName_1 = require("./OdfElementName");
const OFFICE_VERSION = '1.2';
/**
 * Transforms a {@link TextDocument} object into ODF conform XML
 *
 * @since 0.7.0
 */
class TextDocumentWriter {
    constructor() {
        this.fontFaceDeclarationsWriter = new FontFaceDeclarationsWriter_1.FontFaceDeclarationsWriter();
        this.metaWriter = new MetaWriter_1.MetaWriter();
        this.stylesWriter = new StylesWriter_1.StylesWriter();
    }
    /**
     * Transforms the given {@link TextDocument} into Open Document Format.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @returns {Document} The XML document
     * @since 0.7.0
     */
    write(textDocument) {
        const document = new xmldom_1.DOMImplementation().createDocument('urn:oasis:names:tc:opendocument:xmlns:office:1.0', OdfElementName_1.OdfElementName.OfficeDocument, null);
        const root = document.firstChild;
        this.setXmlNamespaces(root);
        this.setOfficeAttributes(root);
        const automaticStyles = new office_1.AutomaticStyles();
        this.writeMeta(textDocument, document, root);
        this.writeFontFaceDeclarations(textDocument, document, root);
        this.writeStyles(textDocument, automaticStyles, document, root);
        this.writeBody(textDocument, automaticStyles, document, root);
        return document;
    }
    /**
     * Declares the used XML namespaces.
     *
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    setXmlNamespaces(root) {
        root.setAttribute('xmlns:dc', 'http://purl.org/dc/elements/1.1/');
        root.setAttribute('xmlns:draw', 'urn:oasis:names:tc:opendocument:xmlns:drawing:1.0');
        root.setAttribute('xmlns:fo', 'urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0');
        root.setAttribute('xmlns:meta', 'urn:oasis:names:tc:opendocument:xmlns:meta:1.0');
        root.setAttribute('xmlns:style', 'urn:oasis:names:tc:opendocument:xmlns:style:1.0');
        root.setAttribute('xmlns:svg', 'urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0');
        root.setAttribute('xmlns:text', 'urn:oasis:names:tc:opendocument:xmlns:text:1.0');
        root.setAttribute('xmlns:xlink', 'http://www.w3.org/1999/xlink');
    }
    /**
     * Sets the mime type and the version attributes.
     *
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    setOfficeAttributes(root) {
        root.setAttribute(OdfAttributeName_1.OdfAttributeName.OfficeMimetype, 'application/vnd.oasis.opendocument.text');
        root.setAttribute(OdfAttributeName_1.OdfAttributeName.OfficeVersion, OFFICE_VERSION);
    }
    /**
     * Adds the meta data to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    writeMeta(textDocument, document, root) {
        this.metaWriter.write(document, root, textDocument.getMeta());
    }
    /**
     * Adds the font face declarations to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    writeFontFaceDeclarations(textDocument, document, root) {
        this.fontFaceDeclarationsWriter.write(textDocument.getFontFaceDeclarations(), document, root);
    }
    /**
     * Adds the styles to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {AutomaticStyles} automaticStyles The automatic styles for the document
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    writeStyles(textDocument, automaticStyles, document, root) {
        new AutomaticStyleVisitor_1.AutomaticStyleVisitor(automaticStyles).visit(textDocument.getBody());
        this.stylesWriter.write(textDocument.getCommonStyles(), document, root);
        this.stylesWriter.write(automaticStyles, document, root);
    }
    /**
     * Adds the documents body to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {AutomaticStyles} automaticStyles The automatic styles for the document
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    writeBody(textDocument, automaticStyles, document, root) {
        new DomVisitor_1.DomVisitor(textDocument.getCommonStyles(), automaticStyles).visit(textDocument.getBody(), document, root);
    }
}
exports.TextDocumentWriter = TextDocumentWriter;
