"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StylesWriter = void 0;
const office_1 = require("../../api/office");
const style_1 = require("../../api/style");
const OdfElementName_1 = require("../OdfElementName");
const ListLevelStyleVisitor_1 = require("./ListLevelStyleVisitor");
const ListStyleVisitor_1 = require("./ListStyleVisitor");
const ParagraphPropertiesVisitor_1 = require("./ParagraphPropertiesVisitor");
const TextPropertiesVisitor_1 = require("./TextPropertiesVisitor");
/**
 * Transforms a {@link StyleManager} object into ODF conform XML
 *
 * NOTE: The properties are set in the order of their appearance in the Realx NG schema.
 *
 * @since 0.9.0
 */
class StylesWriter {
    /**
     * Transforms the given {@link FontFaceDeclarations} into Open Document Format.
     *
     * @param {IStyles} styles The styles to serialize
     * @param {Document} document The XML document
     * @param {Element} parent The parent node in the DOM
     * @since 0.7.0
     */
    write(styles, document, root) {
        const allStyles = styles.getAll();
        if (allStyles.length === 0) {
            return;
        }
        const tagName = styles instanceof office_1.CommonStyles
            ? OdfElementName_1.OdfElementName.OfficeStyles
            : OdfElementName_1.OdfElementName.OfficeAutomaticStyles;
        const stylesElement = document.createElement(tagName);
        root.appendChild(stylesElement);
        allStyles.forEach((style) => this.visitStyle(style, styles, document, stylesElement));
    }
    visitStyle(style, styles, document, parent) {
        const styleElement = this.createStyleElement(style, document);
        parent.appendChild(styleElement);
        this.setName(styleElement, style, styles);
        this.setFamily(styleElement, style);
        this.setClass(styleElement, style);
        if (style instanceof style_1.ListStyle) {
            new ListStyleVisitor_1.ListStyleVisitor().visit(style, styleElement);
            style.getListLevelStyles().forEach((listLevelStyle) => {
                new ListLevelStyleVisitor_1.ListLevelStyleVisitor().visit(listLevelStyle, document, styleElement);
            });
        }
        else if (style instanceof style_1.ParagraphStyle) {
            new ParagraphPropertiesVisitor_1.ParagraphPropertiesVisitor().visit(style, document, styleElement);
            new TextPropertiesVisitor_1.TextPropertiesVisitor().visit(style, document, styleElement);
        }
        return styleElement;
    }
    createStyleElement(style, document) {
        if (style instanceof style_1.ListStyle) {
            return document.createElement(OdfElementName_1.OdfElementName.TextListStyle);
        }
        // else if (style instanceof ParagraphStyle)
        return document.createElement(OdfElementName_1.OdfElementName.StyleStyle);
    }
    setClass(styleElement, style) {
        const clazz = style.getClass();
        if (clazz !== undefined) {
            styleElement.setAttribute('style:class', clazz);
        }
    }
    setFamily(styleElement, style) {
        if (style.getFamily() !== style_1.StyleFamily.None) {
            styleElement.setAttribute('style:family', style.getFamily());
        }
    }
    setName(styleElement, style, styles) {
        const styleName = style.getName();
        if (styleName === style_1.Style.UNNAMED) {
            styleElement.setAttribute('style:name', styles.getName(style));
        }
        else {
            styleElement.setAttribute('style:name', style.getName());
            styleElement.setAttribute('style:display-name', style.getDisplayName());
        }
    }
}
exports.StylesWriter = StylesWriter;
